Changelog
=========

1.3.0 (xx.xx.xx) IN DEVELOPMENT
---------------------------------


1.2.3 (25.07.2016)
---------------------------------

* Added PyPi version and coveralls test coverage badges to README (Andy Babic)
* Altered travis CI test configuration to use tox, allow for much better
  control over test environments (Andy Babic)
* Added tests for Python 3.4 and 3.5 to confirm compatibility (Andy Babic)
* Added CONTRIBUTORS.rst (Andy Babic)


1.2.2 (06.07.2016)
------------------

 * Added this changelog :) (Andy Babic)
 * Added `WAGTAILMENUS_SECTION_ROOT_DEPTH` setting support, for more consistent identification of 'section root' pages (Andy Babic)


